// $Id$
//
// Copyright (C) 2010
//     Stefan Bund <info@j32.de>

/** \file
    \brief PDFWidget non-inline non-template implementation */

#include "PDFWidget.hh"
//#include "PDFWidget.ih"

// Custom includes
#include <iostream>
#include <QNetworkRequest>
#include <QNetworkReply>

//#include "PDFWidget.mpp"
#define prefix_
///////////////////////////////cc.p////////////////////////////////////////

prefix_ pykit::PDFWidget::PDFWidget(QNetworkAccessManager * manager, QWidget * parent)
    : QLabel(parent), manager_ (manager), currentPage_ (0)
{}

prefix_ pykit::PDFWidget::PDFWidget(QString const & document, QNetworkAccessManager * manager,
                                    QWidget * parent)
    : QLabel(parent), manager_ (manager), currentPage_ (0)
{
    document_.reset(Poppler::Document::load(document));
    documentSetup();
    showPage();
}

prefix_ void pykit::PDFWidget::load(QUrl const & url)
{
    QNetworkRequest request (url);
    QNetworkReply * reply (manager_->get(request));
    connect(reply, SIGNAL(finished()), this, SLOT(netLoadDocument()));
}

prefix_ void pykit::PDFWidget::netLoadDocument()
{
    QNetworkReply * reply = static_cast<QNetworkReply*>(sender());
    if (reply->error() != QNetworkReply::NoError)
        return;
    QByteArray data (reply->read(reply->size()));
    document_.reset(Poppler::Document::loadFromData(data));
    documentSetup();
    showPage();
    reply->deleteLater();
}

prefix_ void pykit::PDFWidget::documentSetup()
{
    document_->setRenderHint(Poppler::Document::Antialiasing, true);
    document_->setRenderHint(Poppler::Document::TextAntialiasing, true);
    document_->setRenderHint(Poppler::Document::TextHinting, false);
}

prefix_ void pykit::PDFWidget::showPage()
{
    if (! document_)
        return;
    QImage image (document_->page(currentPage_)->renderToImage(
                      physicalDpiX(), physicalDpiY()));
    setPixmap(QPixmap::fromImage(image));
}

///////////////////////////////cc.e////////////////////////////////////////
#undef prefix_
//#include "PDFWidget.mpp"


// Local Variables:
// mode: c++
// fill-column: 100
// comment-column: 40
// c-file-style: "j32"
// indent-tabs-mode: nil
// ispell-local-dictionary: "american"
// compile-command: "scons -U"
// End:
