// $Id$
//
// Copyright (C) 2010
//     Stefan Bund <info@j32.de>

/** \file
    \brief Viewer non-inline non-template implementation */

#include "Viewer.hh"
//#include "Viewer.ih"

// Custom includes
#include <iostream>
#include <QWebPluginFactory>
#include "Publisher.hh"
#ifdef POPPLER
#include "PDFWidget.hh"
#endif

//#include "Viewer.mpp"
#define prefix_
///////////////////////////////cc.p////////////////////////////////////////

#ifdef POPPLER

namespace {

    class PDFWebPluginFactory
        : public QWebPluginFactory
    {
    public:
        PDFWebPluginFactory(QNetworkAccessManager * manager, QObject * parent = 0);

        QObject * create(QString const & mimeType, QUrl const & url,
                         QStringList const & argumentNames, QStringList const & argumentValues)
            const;
        QList<QWebPluginFactory::Plugin> plugins() const;

    private:
        QNetworkAccessManager * manager_;
    };

}

prefix_ PDFWebPluginFactory::PDFWebPluginFactory(QNetworkAccessManager * manager,
                                                 QObject * parent)
    : QWebPluginFactory(parent), manager_ (manager)
{}

prefix_ QObject * PDFWebPluginFactory::create(QString const & mimeType, QUrl const & url,
                                              QStringList const & /* argumentNames */,
                                              QStringList const & /* argumentValues */)
    const
{
    if (mimeType == "application/pdf") {
        pykit::PDFWidget * plugin = new pykit::PDFWidget(manager_);
        plugin->load(url);
        return plugin;
    }
    return 0;
}

prefix_ QList<QWebPluginFactory::Plugin> PDFWebPluginFactory::plugins()
    const
{
    QList<QWebPluginFactory::Plugin> plugins;

    {
        QWebPluginFactory::Plugin plugin;
        plugin.name = "PDF viewer";
        plugin.description = "View PDF files";
        {
            QWebPluginFactory::MimeType mimeType;
            mimeType.name = "application/pdf";
            mimeType.description = "PDF file";
            plugin.mimeTypes += mimeType;
        }
        plugins += plugin;
    }

    return plugins;
}

#endif

///////////////////////////////////////////////////////////////////////////
// pykit::Viewer

prefix_ pykit::Viewer::Viewer(QUrl const & url, Publisher * publisher, QWidget * parent)
    : QWebView (parent)
{
    QWebSettings::globalSettings()->setAttribute(QWebSettings::PluginsEnabled, true);
    page()->setNetworkAccessManager(
        new InternalNetworkAccessManager(page()->networkAccessManager(), this, publisher));
#ifdef POPPLER
    page()->setPluginFactory(new PDFWebPluginFactory (page()->networkAccessManager(), this));
#endif
    load(url);
}

///////////////////////////////cc.e////////////////////////////////////////
#undef prefix_
//#include "Viewer.mpp"


// Local Variables:
// mode: c++
// fill-column: 100
// comment-column: 40
// c-file-style: "j32"
// indent-tabs-mode: nil
// ispell-local-dictionary: "american"
// compile-command: "scons -U"
// End:
